summaryrefslogtreecommitdiff
path: root/docs
diff options
context:
space:
mode:
Diffstat (limited to 'docs')
-rw-r--r--docs/conf.py18
1 files changed, 9 insertions, 9 deletions
diff --git a/docs/conf.py b/docs/conf.py
index 4f643e9dec..fabe91cc38 100644
--- a/docs/conf.py
+++ b/docs/conf.py
@@ -32,7 +32,7 @@ sys.path.append(abspath(join(dirname(__file__), "_ext")))
# -- General configuration -----------------------------------------------------
# If your documentation needs a minimal Sphinx version, state it here.
-needs_sphinx = '1.6.0'
+needs_sphinx = "4.5.0"
# Add any Sphinx extension module names here, as strings. They can be extensions
# coming with Sphinx (named 'sphinx.ext.*') or your custom ones.
@@ -70,8 +70,8 @@ source_suffix = '.txt'
# The encoding of source files.
# source_encoding = 'utf-8-sig'
-# The master toctree document.
-master_doc = 'contents'
+# The root toctree document.
+root_doc = "contents"
# General substitutions.
project = 'Django'
@@ -102,12 +102,12 @@ else:
django_next_version = '4.0'
extlinks = {
- 'bpo': ('https://bugs.python.org/issue%s', 'bpo-'),
- 'commit': ('https://github.com/django/django/commit/%s', ''),
- 'cve': ('https://nvd.nist.gov/vuln/detail/CVE-%s', 'CVE-'),
+ "bpo": ("https://bugs.python.org/issue?@action=redirect&bpo=%s", "bpo-%s"),
+ "commit": ("https://github.com/django/django/commit/%s", "%s"),
+ "cve": ("https://nvd.nist.gov/vuln/detail/CVE-%s", "CVE-%s"),
# A file or directory. GitHub redirects from blob to tree if needed.
- 'source': ('https://github.com/django/django/blob/main/%s', ''),
- 'ticket': ('https://code.djangoproject.com/ticket/%s', '#'),
+ "source": ("https://github.com/django/django/blob/main/%s", "%s"),
+ "ticket": ("https://code.djangoproject.com/ticket/%s", "#%s"),
}
# The language for content autogenerated by Sphinx. Refer to documentation
@@ -304,7 +304,7 @@ man_pages = [(
# List of tuples (startdocname, targetname, title, author, dir_entry,
# description, category, toctree_only)
texinfo_documents = [(
- master_doc, "django", "", "", "Django",
+ root_doc, "django", "", "", "Django",
"Documentation of the Django framework", "Web development", False
)]